Stan Math Library: stan/math/prim/mat/fun/mdivide_left_spd.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

mdivide_left_spd.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_MDIVIDE_LEFT_SPD_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_MDIVIDE_LEFT_SPD_HPP
3
4 #include <boost/math/tools/promotion.hpp>
5 #include <stan/math/prim/mat/fun/Eigen.hpp>
6 #include <stan/math/prim/mat/fun/promote_common.hpp>
7 #include <stan/math/prim/mat/err/check_multiplicable.hpp>
8 #include <stan/math/prim/mat/err/check_pos_definite.hpp>
9 #include <stan/math/prim/mat/err/check_symmetric.hpp>
10 #include <stan/math/prim/mat/err/check_square.hpp>
11
12 namespace stan {
13 namespace math {
14
24 template <typename T1, typename T2, int R1, int C1, int R2, int C2>
25 inline
26 Eigen::Matrix<typename boost::math::tools::promote_args<T1, T2>::type,
27 R1, C2>
28 mdivide_left_spd(const Eigen::Matrix<T1, R1, C1> &A,
29 const Eigen::Matrix<T2, R2, C2> &b) {
30 stan::math::check_symmetric("mdivide_left_spd", "A", A);
31 stan::math::check_pos_definite("mdivide_left_spd", "A", A);
32 stan::math::check_square("mdivide_left_spd", "A", A);
33 stan::math::check_multiplicable("mdivide_left_spd",
34 "A", A,
35 "b", b);
36 return promote_common<Eigen::Matrix<T1, R1, C1>,
37 Eigen::Matrix<T2, R1, C1> >(A)
38 .llt()
39 .solve(promote_common<Eigen::Matrix<T1, R2, C2>,
40 Eigen::Matrix<T2, R2, C2> >(b));
41 }
42
43 }
44 }
45 #endif
check_multiplicable.hpp
stan
Definition: log_sum_exp.hpp:8
promote_common.hpp
check_symmetric.hpp
stan::math::mdivide_left_spd
Eigen::Matrix< typename boost::math::tools::promote_args< T1, T2 >::type, R1, C2 > mdivide_left_spd(const Eigen::Matrix< T1, R1, C1 > &A, const Eigen::Matrix< T2, R2, C2 > &b)
Returns the solution of the system Ax=b where A is symmetric positive definite.
Definition: mdivide_left_spd.hpp:28
stan::math::promote_common
common_type< T1, T2 >::type promote_common(const F &u)
Definition: promote_common.hpp:14
stan::math::check_multiplicable
bool check_multiplicable(const char *function, const char *name1, const T1 &y1, const char *name2, const T2 &y2)
Return true if the matrices can be multiplied.
Definition: check_multiplicable.hpp:33
Eigen.hpp
stan::math::check_pos_definite
bool check_pos_definite(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified square, symmetric matrix is positive definite.
Definition: check_pos_definite.hpp:37
stan::math::check_symmetric
bool check_symmetric(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is symmetric.
Definition: check_symmetric.hpp:37
stan::math::check_square
bool check_square(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is square.
Definition: check_square.hpp:28
check_pos_definite.hpp
check_square.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.